@@ -22,7 +22,10 @@ pub enum OraDaoError {
     CommitError(String),
 
 }
-
+pub struct UpsertMapInput {
+    pub sql_id: String,
+    pub data: HashMap<String, Value>,
+}
 impl Display for OraDaoError {
     fn fmt(&self, f: &mut Formatter) -> FmtResult {
         let error = to_string_pretty(self).unwrap();
@@ -52,20 +55,20 @@ pub fn execute_dao(sql_id: &str, item: &HashMap<String, Value>) -> Result<usize,
                         }
                         Err(e) => {
                             error!("CommitError:\t{}", e);
-                            Err(OraDaoError::CommitError(format!("{}", e)))
+                            Err(OraDaoError::CommitError(format!("{}\n{}", e, &sql)))
                         }
                     }
                 }
                 Err(e) => {
                     error!("ExecutionError:\t{}", e);
-                    Err(OraDaoError::ExecutionError(format!("{}", e)))
+                    Err(OraDaoError::ExecutionError(format!("{}\n{}", e, &sql)))
                 }
             }
 
         }
         Err(e) => {
             error!("ConnectionError:\t{}", e);
-            Err(OraDaoError::ConnectionError(format!("{}", e)))
+            Err(OraDaoError::ConnectionError(format!("{}\n{}", e, &sql)))
         }
     }
 }
@@ -96,7 +99,48 @@ pub fn execute_multi_entries_dao(sql_id: &str, list : Vec<HashMap<String, Value>
                             Ok(_t) => {}
                             Err(_e) => {}
                         }
-                        return Err(OraDaoError::ExecutionError(format!("{}", e)))
+                        return Err(OraDaoError::ExecutionError(format!("{}\n{}", e, &sql)))
+                    }
+                }
+            }
+            match conn.commit() {
+                Ok(_t) => {
+                    debug!("Commit OK");
+                    Ok(count)
+                }
+                Err(e) => {
+                    error!("CommitError:\t{}", e);
+                    Err(OraDaoError::CommitError(format!("{}", e)))
+                }
+            }
+        }
+        Err(e) => {
+            error!("ConnectionError:\t{}", e);
+            Err(OraDaoError::ConnectionError(format!("{}", e)))
+        }
+    }
+}
+pub fn execute_multi_tables_dao(input: Vec<UpsertMapInput>) -> Result<usize, OraDaoError> {
+
+    return match connect_db() {
+        Ok(conn) => {
+            let mut count = 0;
+
+            for item in input{
+
+                let sql = build_sql(&item.sql_id, "", &item.data);
+
+                match conn.execute(&sql, &[]) {
+                    Ok(_t)=> {
+                        count = count + 1;
+                    }
+                    Err(e) => {
+                        error!("ExecutionError:\t{}", e);
+                        match conn.rollback() {
+                            Ok(_t) => {}
+                            Err(_e) => {}
+                        }
+                        return Err(OraDaoError::ExecutionError(format!("{}\n{}", e, &sql)))
                     }
                 }
             }
